#include "HelloWorldScene.h"
#include <array>

USING_NS_CC;

Scene* HelloWorld::createScene()
{
    // 'scene' is an autorelease object
    auto scene = Scene::create();
    
    // 'layer' is an autorelease object
    auto layer = HelloWorld::create();

    // add layer as a child to scene
    scene->addChild(layer);

    // return the scene
    return scene;
}

// on "init" you need to initialize your instance
bool HelloWorld::init()
{
    //////////////////////////////
    // 1. super init first
    if ( !Layer::init() )
    {
        return false;
    }
    
    Size visibleSize = Director::getInstance()->getVisibleSize();
    Vec2 origin = Director::getInstance()->getVisibleOrigin();

    /////////////////////////////
    // 2. add a menu item with "X" image, which is clicked to quit the program
    //    you may modify it.

    // add a "close" icon to exit the progress. it's an autorelease object
    auto closeItem = MenuItemImage::create(
                                           "CloseNormal.png",
                                           "CloseSelected.png",
                                           CC_CALLBACK_1(HelloWorld::menuCloseCallback, this));
    
	closeItem->setPosition(Vec2(origin.x + visibleSize.width - closeItem->getContentSize().width/2 ,
                                origin.y + closeItem->getContentSize().height/2));

    // create menu, it's an autorelease object
    auto menu = Menu::create(closeItem, NULL);
    menu->setPosition(Vec2::ZERO);
    this->addChild(menu, 1);

    /////////////////////////////
    // 3. add your codes below...

    // add a label shows "Hello World"
    // create and initialize a label
    
    auto label = Label::createWithTTF("Hello World", "fonts/Marker Felt.ttf", 24);
    
    // position the label on the center of the screen
    label->setPosition(Vec2(origin.x + visibleSize.width/2,
                            origin.y + visibleSize.height - label->getContentSize().height));

    // add the label as a child to this layer
    this->addChild(label, 1);

    // add "HelloWorld" splash screen"
    auto sprite = Sprite::create("HelloWorld.png");

    // position the sprite on the center of the screen
    sprite->setPosition(Vec2(visibleSize.width/2 + origin.x, visibleSize.height/2 + origin.y));

    // add the sprite as a child to this layer
    this->addChild(sprite, 0);
    
/* -------- 3-7 図形や線を描く サンプル -------- */
/* 点の描画を試す場合は80〜82行目の、線の描画を試す場合は85〜87行目のコメントアウトを外し、90〜103行目をコメントアウトしてください */
    
    // 点の描画
//    auto drawNode = DrawNode::create();
//    drawNode->drawDot(Vec2(visibleSize/2), 10.0f, Color4F::WHITE);
//    this->addChild(drawNode);
    
    // 線の描画
//    auto drawNode = DrawNode::create();
//    drawNode->drawSegment(Point(0.0f, 0.0f), Point(640.0f, 480.0f), 10.0f, Color4F::WHITE);
//    this->addChild(drawNode);
    
    // 点の格納用
    std::array<Point, 4> vertexes;;
    float bx = origin.x + visibleSize.width / 2;
    float by = origin.y + visibleSize.height / 2;
    float len = 200;
    float weight = 2.0f;
    for (int i = 0; i < vertexes.size(); i++) {
        float deg = (360.0f / vertexes.size()) * i;
        float x = bx + cos(CC_DEGREES_TO_RADIANS(deg)) * len;
        float y = by + sin(CC_DEGREES_TO_RADIANS(deg)) * len;
        vertexes[i].setPoint(x, y);
    }
    auto drawNode = DrawNode::create();
    drawNode->drawPolygon(vertexes.data(), vertexes.size(), Color4F::WHITE, weight, Color4F::GREEN);
    this->addChild(drawNode);
    
/* -------- ここまで -------- */
    
    return true;
}


void HelloWorld::menuCloseCallback(Ref* pSender)
{
    Director::getInstance()->end();

#if (CC_TARGET_PLATFORM == CC_PLATFORM_IOS)
    exit(0);
#endif
}
