#include "HelloWorldScene.h"

USING_NS_CC;

Scene* HelloWorld::createScene()
{
    // 'scene' is an autorelease object
    auto scene = Scene::create();
    
    // 'layer' is an autorelease object
    auto layer = HelloWorld::create();

    // add layer as a child to scene
    scene->addChild(layer);

    // return the scene
    return scene;
}

// on "init" you need to initialize your instance
bool HelloWorld::init()
{
    //////////////////////////////
    // 1. super init first
    if ( !Layer::init() )
    {
        return false;
    }
    
    Size visibleSize = Director::getInstance()->getVisibleSize();
    Vec2 origin = Director::getInstance()->getVisibleOrigin();

    /////////////////////////////
    // 2. add a menu item with "X" image, which is clicked to quit the program
    //    you may modify it.

    // add a "close" icon to exit the progress. it's an autorelease object
    auto closeItem = MenuItemImage::create(
                                           "CloseNormal.png",
                                           "CloseSelected.png",
                                           CC_CALLBACK_1(HelloWorld::menuCloseCallback, this));
    
	closeItem->setPosition(Vec2(origin.x + visibleSize.width - closeItem->getContentSize().width/2 ,
                                origin.y + closeItem->getContentSize().height/2));

    // create menu, it's an autorelease object
    auto menu = Menu::create(closeItem, NULL);
    menu->setPosition(Vec2::ZERO);
    this->addChild(menu, 1);

    /////////////////////////////
    // 3. add your codes below...

    // add a label shows "Hello World"
    // create and initialize a label
    
    auto label = Label::createWithTTF("Hello World", "fonts/Marker Felt.ttf", 24);
    
    // position the label on the center of the screen
    label->setPosition(Vec2(origin.x + visibleSize.width/2,
                            origin.y + visibleSize.height - label->getContentSize().height));

    // add the label as a child to this layer
    this->addChild(label, 1);

    // add "HelloWorld" splash screen"
    auto sprite = Sprite::create("HelloWorld.png");

    // position the sprite on the center of the screen
    sprite->setPosition(Vec2(visibleSize.width/2 + origin.x, visibleSize.height/2 + origin.y));

    // add the sprite as a child to this layer
    this->addChild(sprite, 0);
    
/* -------- 3-8 タッチを実装する サンプル -------- */
/* シングルタッチを有効にする場合は81行目を #if 1、118行目を #if 0、140行目を #if 0 にして下さい */
/* イベントリスナーの優先順位を有効にする場合は81行目を #if 0、118行目を #if 1、140行目を #if 0 にして下さい */
/* マルチタッチの優先順位を有効にする場合は81行目を #if 0、118行目を #if 0、140行目を #if 1 にして下さい */

// シングルタッチ サンプル
#if 0
    // イベントリスナー作成
    auto listener = EventListenerTouchOneByOne::create(); // シングルタッチ

    // イベントを飲み込むかどうか
    listener->setSwallowTouches(true);
    // タッチ開始
    listener->onTouchBegan = [](Touch* touch, Event* event){
        // タッチ開始時の処理を書く
        CCLOG("Touch Began");
        return true;
    };

    // タッチ中
    listener->onTouchMoved = [](Touch* touch, Event* event){
        // タッチ中の処理を書く
        CCLOG("Touch Moved");
    };

    // タッチ終了
    listener->onTouchEnded = [](Touch* touch, Event* event){
        // タッチ終了時の処理を書く
        CCLOG("Touch Ended");
    };

    // タッチキャンセル
    listener->onTouchCancelled = [](Touch* touch, Event* event){
        // タッチキャンセル時の処理を書く
        CCLOG("Touch Cancelled");
    };

    // イベントリスナーを登録
    this->getEventDispatcher()->addEventListenerWithSceneGraphPriority(listener, this);
#endif

// イベントリスナーの優先順位 サンプル
#if 0
    //1 つめのイベントリスナーを作成
    auto listener1 = EventListenerTouchOneByOne::create();
    listener1->onTouchBegan = [](Touch* touch, Event* event){
        log("listener1");
        return true;
    };
    listener1->setSwallowTouches(true);

    //2 つめのイベントリスナーを作成
    auto listener2 = EventListenerTouchOneByOne::create();
    listener2->onTouchBegan = [](Touch* touch, Event* event){
        log("listener2");
        return true;
    };

    //2 つのイベントリスナーを登録
    this->getEventDispatcher()->addEventListenerWithFixedPriority(listener1, 1);
    this->getEventDispatcher()->addEventListenerWithFixedPriority(listener2, 2);
#endif

// マルチタッチ サンプル
#if 1
    // イベントリスナー作成
    auto listener = EventListenerTouchAllAtOnce::create(); // マルチタッチ

    // タッチ開始
    listener->onTouchesBegan = [](const std::vector<cocos2d::Touch *> &touches, Event* event){
        for (auto touch : touches) {
            // タッチ開始時の処理を書く
            CCLOG("Touch Began id=%d", touch->getID());
        }
    };
    
    // CC_CALLBACK_2マクロを使ってメソッドを設定する場合 *メソッドは自前で用意すること
    // listener->onTouchesBegan = CC_CALLBACK_2(HelloWorld::onTouchesBegan, this);

    // イベントリスナーを登録
    this->getEventDispatcher()->addEventListenerWithSceneGraphPriority(listener, this);
#endif

/* -------- ここまで -------- */

    return true;
}


void HelloWorld::menuCloseCallback(Ref* pSender)
{
    Director::getInstance()->end();

#if (CC_TARGET_PLATFORM == CC_PLATFORM_IOS)
    exit(0);
#endif
}
