#include "HelloWorldScene.h"

USING_NS_CC;

Scene* HelloWorld::createScene()
{
    // 'scene' is an autorelease object
    auto scene = Scene::create();
    
    // 'layer' is an autorelease object
    auto layer = HelloWorld::create();

    // add layer as a child to scene
    scene->addChild(layer);

    // return the scene
    return scene;
}

// on "init" you need to initialize your instance
bool HelloWorld::init()
{
    //////////////////////////////
    // 1. super init first
    if ( !Layer::init() )
    {
        return false;
    }
    
    Size visibleSize = Director::getInstance()->getVisibleSize();
    Vec2 origin = Director::getInstance()->getVisibleOrigin();

    /////////////////////////////
    // 2. add a menu item with "X" image, which is clicked to quit the program
    //    you may modify it.

    // add a "close" icon to exit the progress. it's an autorelease object
    auto closeItem = MenuItemImage::create(
                                           "CloseNormal.png",
                                           "CloseSelected.png",
                                           CC_CALLBACK_1(HelloWorld::menuCloseCallback, this));
    
	closeItem->setPosition(Vec2(origin.x + visibleSize.width - closeItem->getContentSize().width/2 ,
                                origin.y + closeItem->getContentSize().height/2));

    // create menu, it's an autorelease object
    auto menu = Menu::create(closeItem, NULL);
    menu->setPosition(Vec2::ZERO);
    this->addChild(menu, 1);

    /////////////////////////////
    // 3. add your codes below...

    // add a label shows "Hello World"
    // create and initialize a label
    
    auto label = Label::createWithTTF("Hello World", "fonts/Marker Felt.ttf", 24);
    
    // position the label on the center of the screen
    label->setPosition(Vec2(origin.x + visibleSize.width/2,
                            origin.y + visibleSize.height - label->getContentSize().height));

    // add the label as a child to this layer
    this->addChild(label, 1);

    // add "HelloWorld" splash screen"
    auto sprite = Sprite::create("HelloWorld.png");

    // position the sprite on the center of the screen
    sprite->setPosition(Vec2(visibleSize.width/2 + origin.x, visibleSize.height/2 + origin.y));

    // add the sprite as a child to this layer
    this->addChild(sprite, 0);
    
/* -------- 3-9 タイマー処理 -------- */

    // 定期的に実行するタイマー
    // test というメソッドを2秒毎に呼び出す場合
    this->schedule(schedule_selector(HelloWorld::test), 2.0f);
    
    // ラムダ式を1秒毎に呼び出す場合
    this->schedule([](float dt){
                           CCLOG("test2");
                       }, 1.0f, "Update Test");
    
    // 1フレームごとに一回 update メソッドを呼び出す場合 * update メソッドをオーバーライドしておく
    this->scheduleUpdate();
    
    
    // 一度だけ実行するタイマー
    // test2 というメソッドを0.5秒後に実行する
    this->scheduleOnce(schedule_selector(HelloWorld::test2), 0.5f);
    
    // ラムダ式を3秒後に呼び出す場合
    this->scheduleOnce([this](float dt){
        this->unschedule(schedule_selector(HelloWorld::test));
        this->unschedule("Update Test");
    }, 3.0f, "Once Test");

    
/* -------- ここまで -------- */
    
    return true;
}

// 定期タイマー用の自前メソッド
void HelloWorld::test(float dt) {
    CCLOG("test");
}

// 定期タイマー用の update メソッド
void HelloWorld::update(float dt) {
    CCLOG("update");
}

// 一度だけ実行するタイマー用の自前メソッド
void HelloWorld::test2(float dt) {
    CCLOG("test2");
    // 定期タイマーの削除（update メソッド）
    this->unscheduleUpdate();
}


void HelloWorld::menuCloseCallback(Ref* pSender)
{
    Director::getInstance()->end();

#if (CC_TARGET_PLATFORM == CC_PLATFORM_IOS)
    exit(0);
#endif
}
